#!/etc/opt/openit/perl -w
#
# File to replace strings in an configuration file. Made for use 
# with Open iT patch program. Use in configuration as follows:
#
#  run:fix_cfg.pl:<config_file>:<str1>:<repld1>:<str2>:<repl2>:...
#
# The program takes a config file to update and pairs of strings
# to replace.
#
use strict;

# First parameter is config file to update
my $cfg = shift (@ARGV);

# Hash to keep match strings and replacement strings
my %reps;

# Get pairs of match/replamentes
while (scalar(@ARGV) > 0) {
    my $key = shift(@ARGV);
    my $val = shift(@ARGV);
    $reps{$key} = $val;
}

my $old = "$cfg.old";
my $new = "$cfg.new";

# Only root can patch
if ( $< ne 0 ) {
    die "Error: Patching must be done as 'root'!\n";
}

# Read old config file into memory
open(IN, "<$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";
my @config = <IN>;
close(IN);

# Go through and try replacements
for(my $i = 0; $i < scalar(@config); $i++) {
    foreach my $key (keys %reps) {
	$config[$i] =~ s/$key/$reps{$key}/g;
    }
}

# Save new config file
open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
foreach (@config) {
    print OUT;
}
close(OUT);

if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}

if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

exit 0;
